Struct ExtBytecode
pub struct ExtBytecode {
instruction_pointer: *const u8,
continue_execution: bool,
bytecode_hash: Option<FixedBytes<32>>,
pub action: Option<InterpreterAction>,
base: Bytecode,
}Expand description
Extended bytecode structure that wraps base bytecode with additional execution metadata.
Fields
instruction_pointer: *const u8continue_execution: boolbytecode_hash: Option<FixedBytes<32>>action: Option<InterpreterAction>Actions that the EVM should do. It contains return value of the Interpreter or inputs for CALL or CREATE instructions.
For RETURN or REVERT instructions it contains the result of the instruction.
base: BytecodeImplementations
impl ExtBytecode
impl ExtBytecode
pub fn new(base: Bytecode) -> ExtBytecode
pub fn new(base: Bytecode) -> ExtBytecode
Create new extended bytecode and set the instruction pointer to the start of the bytecode.
The bytecode hash will not be calculated.
pub fn new_with_hash(base: Bytecode, hash: FixedBytes<32>) -> ExtBytecode
pub fn new_with_hash(base: Bytecode, hash: FixedBytes<32>) -> ExtBytecode
Creates new ExtBytecode with the given hash.
pub fn new_with_optional_hash(
base: Bytecode,
hash: Option<FixedBytes<32>>,
) -> ExtBytecode
pub fn new_with_optional_hash( base: Bytecode, hash: Option<FixedBytes<32>>, ) -> ExtBytecode
Creates new ExtBytecode with the given hash.
pub fn calculate_hash(&mut self) -> FixedBytes<32>
pub fn calculate_hash(&mut self) -> FixedBytes<32>
Re-calculates the bytecode hash.
Prefer get_or_calculate_hash if you just need to get the hash.
pub fn hash(&mut self) -> Option<FixedBytes<32>>
pub fn hash(&mut self) -> Option<FixedBytes<32>>
Returns the bytecode hash.
pub fn get_or_calculate_hash(&mut self) -> FixedBytes<32>
pub fn get_or_calculate_hash(&mut self) -> FixedBytes<32>
Returns the bytecode hash or calculates it if it is not set.
Methods from Deref<Target = Bytecode>
pub fn kind(&self) -> BytecodeKind
pub fn kind(&self) -> BytecodeKind
Returns the kind of bytecode.
pub fn is_eip7702(&self) -> bool
pub fn is_eip7702(&self) -> bool
Returns true if bytecode is EIP-7702.
pub fn eip7702_address(&self) -> Option<Address>
pub fn eip7702_address(&self) -> Option<Address>
Returns the EIP-7702 delegated address if this is EIP-7702 bytecode.
pub fn legacy_jump_table(&self) -> Option<&JumpTable>
pub fn legacy_jump_table(&self) -> Option<&JumpTable>
Returns jump table if bytecode is legacy analyzed.
pub fn hash_slow(&self) -> FixedBytes<32>
pub fn hash_slow(&self) -> FixedBytes<32>
Calculates or returns cached hash of the bytecode.
pub fn bytecode(&self) -> &Bytes
pub fn bytecode(&self) -> &Bytes
Returns a reference to the bytecode bytes.
For legacy bytecode, this includes padding. For EIP-7702, this is the raw bytes.
pub fn bytecode_ptr(&self) -> *const u8
pub fn bytecode_ptr(&self) -> *const u8
Pointer to the bytecode bytes.
pub fn bytes_slice(&self) -> &[u8] ⓘ
pub fn bytes_slice(&self) -> &[u8] ⓘ
Returns the bytecode as a slice.
pub fn original_bytes(&self) -> Bytes
pub fn original_bytes(&self) -> Bytes
Returns the original bytecode without padding.
pub fn original_byte_slice(&self) -> &[u8] ⓘ
pub fn original_byte_slice(&self) -> &[u8] ⓘ
Returns the original bytecode as a byte slice without padding.
pub fn iter_opcodes(&self) -> BytecodeIterator<'_> ⓘ
pub fn iter_opcodes(&self) -> BytecodeIterator<'_> ⓘ
Returns an iterator over the opcodes in this bytecode, skipping immediates.